@@ -218,7 +218,7 @@ from ae.console import ConsoleApp               # type: ignore
 from ae.files import FilesRegister, CachedFile  # type: ignore
 
 
-__version__ = '0.0.6'
+__version__ = '0.0.7'
 
 
 AppStateType = Dict[str, Any]                   #: app state config variable type
@@ -463,7 +463,7 @@ class MainAppBase(ConsoleApp, ABC):
         :param app_state:   dict of app states.
         """
         for key, val in app_state.items():
-            self.change_app_state(key, val)
+            self.change_app_state(key, val, send_event=False)
 
         config_file_version = app_state.get(APP_STATE_VERSION_VAR_NAME, 0)
         for version in range(config_file_version, APP_STATE_CURRENT_VERSION):
@@ -473,11 +473,11 @@ class MainAppBase(ConsoleApp, ABC):
             elif version == 1:
                 key, val = 'sound_volume', 1.0
             if key:
-                self.change_app_state(key, val)
+                self.change_app_state(key, val, send_event=False)
                 self.set_var(key, val, section=APP_STATE_SECTION_NAME)
         if config_file_version < APP_STATE_CURRENT_VERSION:
             key, val = APP_STATE_VERSION_VAR_NAME, APP_STATE_CURRENT_VERSION
-            self.change_app_state(key, val)
+            self.change_app_state(key, val, send_event=False)
             self.set_var(key, val, section=APP_STATE_SECTION_NAME)
 
     def _update_observable_app_states(self, app_state: AppStateType):
